\name{convert.affy}
\alias{convert.affy}

\title{Decodes CEL files}
\description{Decodes CEL files, using the necesary CDF file, and creates
  a simple table with relevant probe pair information.}
}
\usage{
convert.affy(file, CDFfile=NULL, CELfiles=NULL, read=T, chip.names=NULL, keep.controls=F)
}
\arguments{
  \item{file}{the name of the file which the data are to be written to.}
  \item{CDFfile}{the name of the CDF file to be used for decoding the
    CEL files. If both \code{CDFfile} and \code{CELfile} are NULL,
    \code{convert.affy} looks for files in the current directory.}
  \item{CELfiles}{a character vector containing the names of the CEL files
    that will be decoded. If both \code{CDFfile} and \code{CELfile} are \code{NULL}, \code{convert.affy} looks for files in the current directory.}
  \item{path}{character string containing the path where
    \code{\link{cel2tab.pl}} is located. This is not necesary if \code{\link{cel2tab.pl}} is a shell command. See Details.}
  \item{read}{logical value. If \code{TRUE} the function
    \code{\link{read.affy}} is invoked and an \code{\link{affy.object}}
      is returned.} 
  \item{chip.names}{a character vector containing the names to be
    used for the different chips. If \code{read=F} this is ignored.}
  \item{keep.controls}{a logical value indicating if the information
    from the control pairs should be retured.  If \code{read=F} this is ignored.}}
}
\details{
For this function to work the perl script \code{\link{cel2tab.pl}} must be
executable and properly installed. This script does the bulk of the
work. An alternative to using \code{convert.affy} is to convert the CEL
files first (before invoking R) using the script and then reading in the
data using \code{\link{read.affy}}.

If \code{chip.names} is \code{NULL} then then \code{read.affy} uses the
names of the CEL with the suffix .CEL removed.
}
\value{If \code{read=T} this function returns NULL. Otherwise it returns
  an \code{\link{affy.object}} with components:
  \item{nchips}{number of chips.}
  \item{nprob}{number of probe pairs.}
  \item{probe.names}{a characater vector of length \code{nprob} with the
    probe names for each probe pair.}
  \item{pm }{a \code{nprob} by \code{nchips} matrix with the pm intensities.}
  \item{mm }{a \code{nprob} by \code{nchips} matrix with the mm intensities.}
  \item{chip.names}{a character vector of length nchips with the names
    of each chip.}
  \item{probe.number}{the probe number for each probe} 
  \item{x}{a vector containing the row number of the pm, for each
    probe pair, on the chips.}
  \item{y}{a vector containing the column number of the pm, for each
    probe pair, on the chips.}
  \item{ncol}{the number of rows on the chips.}
  \item{nrow}{the number of columns on the chips.}
}

\references{ Affymetrix (1999) Gene Chip Analysis Suite User Guide
  (Affymetrix, Santa Clara)}
\author{Rafael A. Irizarry}
%\note{ ~~further notes~~ }
\seealso{ \code{\link{read.affy}}}

%\examples{
%#---- Should be DIRECTLY executable !! ----
%#-- ==>  Define data, use random,
%#--	     or do  help(data=index)  for the standard data sets.
\keyword{affy}%-- one or more ...
\keyword{Affymetrics}
\keyword{convert}