\name{li.wong}
\alias{li.wong}
\title{Fit Li and Wong model}
\description{Fits the model described in Li and Wong (2001) to all probes
in an \code{\link{affy.object}}.}
\usage{
li.wong(x, subset=NULL, ignore.mm=F, remove.outliers=T, normal.array.quantile=0.5, normal.resid.quantile=0.9, large.threshold=3, large.variation=0.8, outlier.fraction=0.14, delta=1e-06, maxit=50, outer.maxit=50, verbose=F)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{an \code{affy.object} }
  \item{subset}{a logical vector or numerical vector describing which
    probes to perform analysis on.}
  \item{ignore.mm}{ logical value. If true we perform analysis on pm
    otherwise we perform analysis on pm-mm}
  \item{remove.outliers}{logical value indicating if the algorithm
    will remove outliers according to the procedure described in Li and
    Wong (2001).}
  \item{large.threshold}{used to define outliers.}
  \item{normal.array.quantile}{quantile to be used when determining what
    a normal SD is. probes or chips having estimates with SDs bigger
    than the quantile \code{normal.array.quantile} of all SDs x
    \code{large.threshold} }
  \item{normal.resid.quantile}{any residual  bigger than the
    \code{normal.resid.quantile} quantile of all residuals x
    \code{large.threshold} is considered an outlier}
  \item{large.variation}{any probe or chip describing more than this
    much total variation is considered an outlier}
  \item{outlier.fraction}{this is the maximum fraction of single
    outliers that can be in the same probe or chip.}
  \item{delta}{ numerical value used to define the stopping
    criterion. }
  \item{maxit}{ maximum number of iterations when fitting the model.}
  \item{outer.maxit}{ maxumum number of iterations of defined outliers.}
  \item{verbose}{logical value. If \code{TRUE} information is given of
    the status of the algorithm.}
}
\details{Please refer to references.}

}
\value{A list with components:
  \item{probe.name}{a character vector containing the probe names.}
  \item{theta}{a matrix containing the estimated thetas for each probe}
  \item{sigma.theta}{a matrix containing the estimated standard errors
    of theta}
  \item{sigma.eps=sigma.eps}{a vector containing the estimated stadared 
    devations of the noise}
  \item{outlier}{a matrix describing which theta is associated with an
    outlier chip}
  \item{convergence1}{a logical vector describing which probes did not converge
    when estimating the thetas and phis}
  \item{convergence2}{a logical vector describing which probes did not
    converge in decided on ouliers}
}
\references{Li, C. and Wong, W.H. (2001) Genome Biology 2, 1-11,
  Li, C. and Wong, W.H. (2001) Proc. Natl. Acad. Sci USA 98, 31-6}
\author{Rafael A. Irizarry}
\seealso{ \code{\link{fit.li.wong}}}
\keyword{affy}
